@@ -477,8 +477,8 @@ def norm_string_to_integer(s):
     return ii
 
 
-@njit((complex128, float64, float64[:], int32), cache=True)
-def _mie_S1_S2(m, x, mu, norm_int):
+@njit((complex128, float64, float64[:], int32, int32), cache=True)
+def _mie_S1_S2(m, x, mu, norm_int, nth):
     """
     Calculate the scattering amplitude functions for spheres.
 
@@ -492,6 +492,7 @@ def _mie_S1_S2(m, x, mu, norm_int):
         x: the size parameter of the sphere
         mu: array of angles, cos(theta), to calculate scattering amplitudes
         norm_int: integer describing type of normalization
+        nth: return nth term from series (default=0 means include all terms)
 
     Returns:
         S1, S2: the scattering amplitudes at each angle mu [sr**(-0.5)]
@@ -508,8 +509,9 @@ def _mie_S1_S2(m, x, mu, norm_int):
         pi_nm1 = 1
         for n in range(1, nstop):
             tau_nm1 = n * mu[k] * pi_nm1 - (n + 1) * pi_nm2
-            S1[k] += (2 * n + 1) * (pi_nm1 * a[n - 1] + tau_nm1 * b[n - 1]) / (n + 1) / n
-            S2[k] += (2 * n + 1) * (tau_nm1 * a[n - 1] + pi_nm1 * b[n - 1]) / (n + 1) / n
+            if nth in (0, n):
+                S1[k] += (2 * n + 1) * (pi_nm1 * a[n - 1] + tau_nm1 * b[n - 1]) / (n + 1) / n
+                S2[k] += (2 * n + 1) * (tau_nm1 * a[n - 1] + pi_nm1 * b[n - 1]) / (n + 1) / n
             temp = pi_nm1
             pi_nm1 = ((2 * n + 1) * mu[k] * pi_nm1 - (n + 1) * pi_nm2) / n
             pi_nm2 = temp
@@ -522,7 +524,7 @@ def _mie_S1_S2(m, x, mu, norm_int):
     return [S1, S2]
 
 
-def mie_S1_S2(m, x, mu, norm='albedo'):
+def mie_S1_S2(m, x, mu, norm='albedo', nth=0):
     """
     Calculate the scattering amplitude functions for spheres.
 
@@ -538,6 +540,7 @@ def mie_S1_S2(m, x, mu, norm='albedo'):
         x: the size parameter of the sphere
         mu: cos(theta) or array of angles [cos(theta_i)]
         norm: (optional) string describing scattering function normalization
+        nth: return nth term from series (default=0 means include all terms)
 
     Returns:
         S1, S2: the scattering amplitudes at each angle mu [sr**(-0.5)]
@@ -545,10 +548,10 @@ def mie_S1_S2(m, x, mu, norm='albedo'):
     norm_int = norm_string_to_integer(norm)
     if np.isscalar(mu):
         mu_array = np.array([mu], dtype=float)
-        s1, s2 = _mie_S1_S2(m, x, mu_array, norm_int)
+        s1, s2 = _mie_S1_S2(m, x, mu_array, norm_int, nth)
         return s1[0], s2[0]
 
-    return _mie_S1_S2(m, x, mu, norm_int)
+    return _mie_S1_S2(m, x, mu, norm_int, nth)
 
 
 def mie_phase_matrix(m, x, mu, norm='albedo'):
@@ -715,7 +718,7 @@ def generate_mie_costheta(mu_cdf):
     return x
 
 
-def i_per(m, x, mu, norm='albedo'):
+def i_per(m, x, mu, norm='albedo', nth=0):
     """
     Return the scattered intensity in a plane normal to the incident light.
 
@@ -734,16 +737,17 @@ def i_per(m, x, mu, norm='albedo'):
         x: the size parameter of the sphere
         mu: the angles, cos(theta), to calculate intensities
         norm: (optional) string describing scattering function normalization
+        nth: return nth term from series (default=0 means include all terms)
 
     Returns:
         The intensity at each angle in the array mu.  Units [1/sr]
     """
-    s1, _ = mie_S1_S2(m, x, mu, norm)
+    s1, _ = mie_S1_S2(m, x, mu, norm, nth)
     intensity = np.abs(s1)**2
     return intensity.astype('float')
 
 
-def i_par(m, x, mu, norm='albedo'):
+def i_par(m, x, mu, norm='albedo', nth=0):
     """
     Return the scattered intensity in a plane parallel to the incident light.
 
@@ -762,16 +766,17 @@ def i_par(m, x, mu, norm='albedo'):
         x: the size parameter of the sphere
         mu: the angles, cos(theta), to calculate intensities
         norm: (optional) string describing scattering function normalization
+        nth: return nth term from series (default=0 means include all terms)
 
     Returns:
         The intensity at each angle in the array mu.  Units [1/sr]
     """
-    _, s2 = mie_S1_S2(m, x, mu, norm)
+    _, s2 = mie_S1_S2(m, x, mu, norm, nth)
     intensity = np.abs(s2)**2
     return intensity.astype('float')
 
 
-def i_unpolarized(m, x, mu, norm='albedo'):
+def i_unpolarized(m, x, mu, norm='albedo', nth=0):
     """
     Return the unpolarized scattered intensity at specified angles.
 
@@ -789,11 +794,12 @@ def i_unpolarized(m, x, mu, norm='albedo'):
         x: the size parameter of the sphere
         mu: the angles, cos(theta), to calculate intensities
         norm: (optional) string describing scattering function normalization
+        nth: return nth term from series (default=0 means include all terms)
 
     Returns:
         The intensity at each angle in the array mu.  Units [1/sr]
     """
-    s1, s2 = mie_S1_S2(m, x, mu, norm)
+    s1, s2 = mie_S1_S2(m, x, mu, norm, nth)
     intensity = (np.abs(s1)**2 + np.abs(s2)**2) / 2
     return intensity.astype('float')
 
@@ -819,7 +825,7 @@ def ez_mie(m, d, lambda0, n_env=1.0):
     return mie(m_env, x_env)
 
 
-def ez_intensities(m, d, lambda0, mu, n_env=1.0, norm='albedo'):
+def ez_intensities(m, d, lambda0, mu, n_env=1.0, norm='albedo', nth=0):
     """
     Return the scattered intensities from a sphere.
 
@@ -844,6 +850,7 @@ def ez_intensities(m, d, lambda0, mu, n_env=1.0, norm='albedo'):
         mu: the cos(theta) of each direction desired     [-]
         n_env: real index of medium around sphere, optional
         norm: (optional) string describing scattering function normalization
+        nth: return nth term from series (default=0 means include all terms)
 
     Returns:
         ipar, iper: scattered intensity in parallel and perpendicular planes [1/sr]
@@ -851,7 +858,7 @@ def ez_intensities(m, d, lambda0, mu, n_env=1.0, norm='albedo'):
     m_env = m / n_env
     lambda_env = lambda0 / n_env
     x_env = np.pi * d / lambda_env
-    s1, s2 = mie_S1_S2(m_env, x_env, mu, norm)
+    s1, s2 = mie_S1_S2(m_env, x_env, mu, norm, nth)
     ipar = np.abs(s2)**2
     iper = np.abs(s1)**2
     Ipar = ipar.astype('float')
